@@ -5,6 +5,7 @@ def LPP_data_multi(performance_df, number_of_acq_points, time_slots, location_sl
     
     #packages
     import numpy as np
+    import pandas as pd
     #import progressbar
 
     #bar = progressbar.ProgressBar(len(location_slots)*performance_df.shape[0]+7)
@@ -18,7 +19,7 @@ def LPP_data_multi(performance_df, number_of_acq_points, time_slots, location_sl
     #functions
     #conversion into cartesian coordinate system. Note R is appr. radius of earth 6371 km
     def cart_system(lat, lon, elevation):
-        import numpy as np 
+        #import numpy as np 
         lat = np.radians(lat)
         lon = np.radians(lon)
         R = 6371 + elevation
@@ -27,13 +28,23 @@ def LPP_data_multi(performance_df, number_of_acq_points, time_slots, location_sl
         z = R * np.sin(lat)
         return(np.array([x,y,z]))
     #identify doubles
+    # def insert_row(idx, df, df_insert):
+    #     #import pandas as pd
+    #     dfA = df.iloc[:idx, ]
+    #     dfB = df.iloc[idx:, ]
+    #     df = pd.concat([dfA,df_insert,dfB])
+    #     #df = dfA.append(df_insert).append(dfB).reset_index(drop = True)
+    #     return(df)
     def insert_row(idx, df, df_insert):
-        import pandas as pd
-        dfA = df.iloc[:idx, ]
-        dfB = df.iloc[idx:, ]
-        df = pd.concat([dfA,df_insert,dfB])
-        #df = dfA.append(df_insert).append(dfB).reset_index(drop = True)
+        # Ensure df_insert has the same columns as the DataFrame
+        df_insert = df_insert.to_frame().T
+        df_insert.columns = df.columns
+        # Split the DataFrame into two parts and insert the new row
+        dfA = df.iloc[:idx, ].copy()
+        dfB = df.iloc[idx:, ].copy()
+        df = pd.concat([dfA, df_insert, dfB]).reset_index(drop=True)
         return(df)
+    
     #repeat element n times 
     def repeatelem(elem, n):
         #returns an array with element elem repeated n times.
@@ -163,7 +174,8 @@ def LPP_data_multi(performance_df, number_of_acq_points, time_slots, location_sl
     #### max h attempt per REQUEST
     #how many is inserted of the requests?
     string_list = list()
-    BB = list(performance_df["request location"])
+    
+    BB = [[float(l[0]), float(l[1])] for l in performance_df["request location"]]
     string_list = list(set(list(map(str, BB))))
 
     number_of_reach_areas = len(string_list)
